@@ -41,7 +41,8 @@ def _convert_to_float_if_possible(s: str) -> float | str:
 
 
 def _parse_boolean(val: str) -> str | bool:
-    """Try to parse a string into boolean.
+    """
+    Try to parse a string into boolean.
 
     Raises ValueError if the input is not a valid true- or false-like string value.
     """
@@ -152,22 +153,6 @@ class BaseSQLOperator(BaseOperator):
         conn = BaseHook.get_connection(conn_id)
         hook = conn.get_hook(hook_params=self.hook_params)
         if not isinstance(hook, DbApiHook):
-            from airflow.hooks.dbapi_hook import DbApiHook as _DbApiHook
-
-            if isinstance(hook, _DbApiHook):
-                # This case might happen if user installed common.sql provider but did not upgrade the
-                # Other provider's versions to a version that supports common.sql provider
-                class_module = hook.__class__.__module__
-                match = _PROVIDERS_MATCHER.match(class_module)
-                if match:
-                    provider = match.group(1)
-                    min_version = _MIN_SUPPORTED_PROVIDERS_VERSION.get(provider)
-                    if min_version:
-                        raise AirflowException(
-                            f"You are trying to use common-sql with {hook.__class__.__name__},"
-                            f" but the Hook class comes from provider {provider} that does not support it."
-                            f" Please upgrade provider {provider} to at least {min_version}."
-                        )
             raise AirflowException(
                 f"You are trying to use `common-sql` with {hook.__class__.__name__},"
                 " but its provider does not support it. Please upgrade the provider to a version that"
@@ -177,7 +162,10 @@ class BaseSQLOperator(BaseOperator):
             )
 
         if self.database:
-            hook.schema = self.database
+            if hook.conn_type == "postgres":
+                hook.database = self.database
+            else:
+                hook.schema = self.database
 
         return hook
 
